Crate kcr_servicebinding_io

Crate kcr_servicebinding_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the servicebinding.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

servicebinding.io/v1alpha3

  • ClusterWorkloadResourceMapping
  • ServiceBinding

servicebinding.io/v1beta1

  • ClusterWorkloadResourceMapping
  • ServiceBinding

Modules

v1alpha3
v1beta1